@@ -40,7 +40,7 @@ typedef struct {
 } directDeviceInfo_t;
 
 
-#include "cpp_extern_macro.h"
+//#include "cpp_extern_macro.h"
 BEGIN_C_DECLS;
 
 /*!
