@@ -4,9 +4,9 @@
 /*!
   \file
   \brief ԗւ̒ړIȉ]x
-  
+
   \author Satofumi KAMIMURA
-  
+
   $Id$
 */
 
@@ -21,7 +21,7 @@ typedef struct {
 } directWheelInfo_t;
 
 
-#include "cpp_extern_macro.h"
+//#include "cpp_extern_macro.h"
 BEGIN_C_DECLS;
 
 extern void initDirectWheelCtrlInfo(directWheelInfo_t *directWhl);
