@@ -1,6 +1,9 @@
-/*
-  ^[Qbgp̑svO
-  Satofumi KAMIMURA
+/*!
+  \file
+  \brief ^[Qbgp̑svO
+
+  \author Satofumi KAMIMURA
+
   $Id$
 */
 
