@@ -22,7 +22,7 @@ typedef struct {
 } velocityInfo_t;
 
 
-#include "cpp_extern_macro.h"
+//#include "cpp_extern_macro.h"
 BEGIN_C_DECLS;
 
 extern void initVelocityInfo(velocityInfo_t *vel);
